@@ -5,14 +5,10 @@ from os.path import abspath, join, isdir, pardir, isfile, dirname
 from io import BytesIO
 import pickle
 
-from .definition import KIMPropertyError
-from .instance import get_property_id_path
+import kim_edn
 
-try:
-    import kim_edn
-except:
-    msg = '\nERROR: Failed to import the `kim_edn` utility module.'
-    raise KIMPropertyError(msg)
+from .err import KIMPropertyError
+from .instance import get_property_id_path
 
 __all__ = [
     "pickle_kim_properties",
@@ -58,7 +54,7 @@ def pickle_kim_properties(properties=None,
         if isdir(abspath(kim_property_files_path)):
             kim_property_files_path = abspath(kim_property_files_path)
         else:
-            msg = '\nERROR: property files can not be found!'
+            msg = 'property files can not be found!'
             raise KIMPropertyError(msg)
 
         # KIM property names.
@@ -82,6 +78,7 @@ def pickle_kim_properties(properties=None,
             "configuration-nonorthogonal-periodic-3d-cell-relaxed-particles-fixed",
             "configuration-nonorthogonal-periodic-3d-cell-relaxed-particles-relaxed",
             "configuration-periodic-2d-cell-fixed-particles-fixed",
+            "dislocation-core-energy-cubic-crystal-npt",
             "elastic-constants-first-strain-gradient-isothermal-cubic-crystal-npt",
             "elastic-constants-first-strain-gradient-isothermal-monoatomic-hexagonal-crystal-npt",
             "elastic-constants-isothermal-cubic-crystal-npt",
@@ -142,6 +139,7 @@ def pickle_kim_properties(properties=None,
             "tag:staff@noreply.openkim.org,2014-04-15:property/configuration-nonorthogonal-periodic-3d-cell-relaxed-particles-fixed",
             "tag:staff@noreply.openkim.org,2014-04-15:property/configuration-nonorthogonal-periodic-3d-cell-relaxed-particles-relaxed",
             "tag:staff@noreply.openkim.org,2015-10-12:property/configuration-periodic-2d-cell-fixed-particles-fixed",
+            "tag:staff@noreply.openkim.org,2019-07-24:property/dislocation-core-energy-cubic-crystal-npt",
             "tag:staff@noreply.openkim.org,2016-05-24:property/elastic-constants-first-strain-gradient-isothermal-cubic-crystal-npt",
             "tag:staff@noreply.openkim.org,2016-05-24:property/elastic-constants-first-strain-gradient-isothermal-monoatomic-hexagonal-crystal-npt",
             "tag:staff@noreply.openkim.org,2014-05-21:property/elastic-constants-isothermal-cubic-crystal-npt",
@@ -185,9 +183,9 @@ def pickle_kim_properties(properties=None,
             _path, _, _, _ = get_property_id_path(_id)
             kim_property_files.append(join(kim_property_files_path, _path))
             if not isfile(kim_property_files[-1]):
-                msg = '\nERROR: the property file =\n"'
+                msg = 'the property file =\n"'
                 msg += kim_property_files[-1]
-                msg += '"\n can not be found!'
+                msg += '"\ncan not be found!'
                 raise KIMPropertyError(msg)
 
         del(kim_property_files_path)
@@ -214,11 +212,11 @@ def pickle_kim_properties(properties=None,
         ]
     else:
         if not (isinstance(properties, dict)):
-            msg = '\nERROR: wrong input, "properties" is not a `dict`.'
+            msg = 'wrong input, "properties" is not a `dict`.'
             raise KIMPropertyError(msg)
 
         if len(properties) == 0:
-            msg = '\nERROR: wrong input, "properties" is empty.'
+            msg = 'wrong input, "properties" is empty.'
             raise KIMPropertyError(msg)
 
         property_ids = [k for k in properties]
@@ -254,8 +252,7 @@ def pickle_kim_properties(properties=None,
         try:
             pickle.dump(kim_properties_list, fp, protocol=protocol)
         except:
-            msg = '\nERROR: wrong input. ("fp" should refer to a bytes-like '
-            msg += 'object.)'
+            msg = 'wrong input. ("fp" should refer to a bytes-like object.)'
             raise KIMPropertyError(msg)
 
 
@@ -283,15 +280,14 @@ def unpickle_kim_properties(fp=join(kim_properties_path, 'kim_properties.pickle'
             with open(fp, 'rb') as f:
                 return pickle.load(f)
 
-        msg = '\nERROR: wrong input. Can\'t load pickle from unicode '
-        msg += 'string.\n If "fp" refers to a file name, make sure it '
-        msg += 'exists in PATH or provide the file name with its '
-        msg += 'absolute PATH.'
+        msg = 'wrong input. Can\'t load pickle from unicode string.\n'
+        msg += 'If "fp" refers to a file name, make sure it exists in PATH '
+        msg += 'or provide the file name with its absolute PATH.'
         raise KIMPropertyError(msg)
     else:
         try:
             f = BytesIO(fp)
             return pickle.load(f)
         except:
-            msg = '\nERROR: wrong input. Can not open nor load the input.'
+            msg = 'wrong input. Neither can open nor load the input.'
             raise KIMPropertyError(msg)
