@@ -315,6 +315,48 @@ class TestPropertyModule:
         self.assertTrue("cohesive-potential-energy" in kim_obj)
         self.assertTrue("basis-atom-coordinates" in kim_obj)
 
+        # Fail when there is no property instance to remove the content.
+        for str_obj1 in [None, 'None', '', '[]']:
+            self.assertRaises(self.KIMPropertyError,
+                              self.kim_property.kim_property_remove,
+                              str_obj1, 1, "key", "a")
+
+        # Fails when the "instance_id" is not an `int`.
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_remove,
+                          str_obj, 1.0, "key", "a")
+
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_remove,
+                          str_obj, "1", "key", "a")
+
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_remove,
+                          str_obj, [1], "key", "a")
+
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_remove,
+                          str_obj, {1}, "key", "a")
+
+        # Fails when the requested instance id doesn\'t match any 
+        # of the property instances ids.
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_remove,
+                          str_obj, 10, "key", "a")
+
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_remove,
+                          str_obj, 2, "key", "a")
+
+        # Fails when the key doesn\'t exist in the property instance.
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_remove,
+                          str_obj, 1, "key", "new_item")
+
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_remove,
+                          str_obj, 1, "key", "aa")
+
         # Removing the whole key
         str_obj1 = self.kim_property.kim_property_remove(
             str_obj, 1, "key", "a")
@@ -410,6 +452,13 @@ class TestPropertyModule:
         out_str = kim_edn.dumps(kim_obj, indent=0) + '\n'
 
         sio = StringIO()
+
+        # Fail when there is no property instance to dump it.
+        for str_obj1 in [None, 'None', '', '[]']:
+            self.assertRaises(self.KIMPropertyError,
+                              self.kim_property.kim_property_dump,
+                              str_obj1, sio)
+
         self.kim_property.kim_property_dump(str_obj, sio, indent=0)
 
         self.assertTrue(sio.getvalue() == out_str)
@@ -419,6 +468,11 @@ class TestPropertyModule:
                           self.kim_property.kim_property_modify,
                           str_obj, "output/results.edn")
 
+        str_obj = self.kim_property.kim_property_create(
+            2, 'atomic-mass', str_obj)
+
+        self.kim_property.kim_property_dump(str_obj, sio, indent=0)
+
 
 class TestPyTestPropertyModule(TestPropertyModule, PyTest):
     pass
